pub struct BitReader<'a> { /* private fields */ }Expand description
MSB-first bit reader over a byte slice.
Implementations
Sourceimpl<'a> BitReader<'a>
impl<'a> BitReader<'a>
pub fn new(data: &'a [u8]) -> Self
Sourcepub fn bit_position(&self) -> u64
pub fn bit_position(&self) -> u64
Current read offset in bits, measured from the start of the input.
pub fn bits_remaining(&self) -> u64
pub fn is_byte_aligned(&self) -> bool
Sourcepub fn align_to_byte(&mut self)
pub fn align_to_byte(&mut self)
Discard bits up to the next byte boundary (7.2 byte_aligned()).